==> owncloud-8.1.0p2.tgz: owncloud/apps/files/l10n/es_AR.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "Error desconocido",
    "Could not move %s - File with this name already exists" : "No se pudo mover %s - Un archivo con este nombre ya existe",
    "Could not move %s" : "No se pudo mover %s ",
    "The name %s is already used in the folder %s. Please choose a different name." : "El nombre %s está en uso en el directorio %s. Por favor elija un otro nombre.",
    "Error when creating the file" : "Error al crear el archivo",
    "Error when creating the folder" : "Error al crear el directorio",
    "Unable to set upload directory." : "No fue posible crear el directorio de subida.",
    "Invalid Token" : "Token Inválido",
    "No file was uploaded. Unknown error" : "El archivo no fue subido. Error desconocido",
    "There is no error, the file uploaded with success" : "No hay errores, el archivo fue subido con éxito",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "El archivo que intentás subir excede el tamaño definido por upload_max_filesize en el php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa el valor MAX_FILE_SIZE especificada en el formulario HTML",
    "The uploaded file was only partially uploaded" : "El archivo fue subido parcialmente",
    "No file was uploaded" : "No se subió ningún archivo ",
    "Missing a temporary folder" : "Falta un directorio temporal",
    "Failed to write to disk" : "Error al escribir en el disco",
    "Not enough storage available" : "No hay suficiente almacenamiento",
    "Upload failed. Could not find uploaded file" : "Falló la carga. No se pudo encontrar el archivo subido.",
    "Upload failed. Could not get file info." : "Falló la carga. No se pudo obtener la información del archivo.",
    "Invalid directory." : "Directorio inválido.",
    "Files" : "Archivos",
    "Favorites" : "Favoritos",
    "Home" : "Particular",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Imposible cargar {filename} puesto que es un directoro o tiene 0 bytes.",
    "Upload cancelled." : "La subida fue cancelada",
    "Could not get result from server." : "No se pudo obtener resultados del servidor.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La subida del archivo está en proceso. Si salís de la página ahora, la subida se cancelará.",
    "{new_name} already exists" : "{new_name} ya existe",
    "Could not create file" : "No se pudo crear el archivo",
    "Could not create folder" : "No se pudo crear el directorio",
    "Rename" : "Cambiar nombre",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "Download" : "Descargar",
    "Select" : "Seleccionar",
    "Pending" : "Pendientes",
    "Error moving file" : "Error moviendo el archivo",
    "Error" : "Error",
    "Could not rename file" : "No se pudo renombrar el archivo",
    "Error deleting file." : "Error al borrar el archivo.",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "You don’t have permission to upload or create files here" : "No tienes permisos para subir o crear archivos aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
    "File name cannot be empty." : "El nombre del archivo no puede quedar vacío.",
    "Your storage is full, files can not be updated or synced anymore!" : "El almacenamiento está lleno, los archivos no se pueden seguir actualizando ni sincronizando",
    "Your storage is almost full ({usedSpacePercent}%)" : "El almacenamiento está casi lleno ({usedSpacePercent}%)",
    "{dirs} and {files}" : "{carpetas} y {archivos}",
    "Favorite" : "Favorito",
    "A new file or folder has been <strong>created</strong>" : "Un archivo o carpeta ha sido <strong>creado</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un archivo o carpeta ha sido <strong>modificado</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>eliminado</strong>",
    "You created %1$s" : "Has creado %1$s",
    "%2$s created %1$s" : "%2$s creó %1$s",
    "You changed %1$s" : "Modificaste %1$s",
    "%2$s changed %1$s" : "%2$s modificó %1$s",
    "You deleted %1$s" : "Eliminaste %1$s",
    "%2$s deleted %1$s" : "%2$s eliminó %1$s",
    "%s could not be renamed" : "No se pudo renombrar %s",
    "File handling" : "Tratamiento de archivos",
    "Maximum upload size" : "Tamaño máximo de subida",
    "max. possible: " : "máx. posible:",
    "Save" : "Guardar",
    "Settings" : "Configuración",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Usar esta dirección para <a href=\"%s\" target=\"_blank\">acceder a tus archivos vía WebDAV</a>",
    "New" : "Nuevo",
    "New text file" : "Nuevo archivo de texto",
    "Text file" : "Archivo de texto",
    "New folder" : "Nueva Carpeta",
    "Folder" : "Carpeta",
    "Upload" : "Subir",
    "Cancel upload" : "Cancelar subida",
    "Upload too large" : "El tamaño del archivo que querés subir es demasiado grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que intentás subir sobrepasan el tamaño máximo ",
    "Files are being scanned, please wait." : "Se están escaneando los archivos, por favor esperá."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/es_AR.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Almacenamiento invalido",
    "Unknown error" : "Error desconocido",
    "All files" : "Todos los archivos",
    "Saved" : "Guardado",
    "Home" : "Particular",
    "Close" : "Cerrar",
    "Favorites" : "Favoritos",
    "Upload cancelled." : "La subida fue cancelada",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Imposible cargar {filename} puesto que es un directoro o tiene 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hay suficiente espacio libre. Quiere subir {size1} pero solo quedan {size2}",
    "Uploading..." : "Subiendo...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La subida del archivo está en proceso. Si salís de la página ahora, la subida se cancelará.",
    "Actions" : "Acciones",
    "Download" : "Descargar",
    "Rename" : "Cambiar nombre",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "Files" : "Archivos",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendientes",
    "Unable to determine date" : "No fue posible determinar la fecha",
    "Invalid path" : "Ruta no válida",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "{dirs} and {files}" : "{carpetas} y {archivos}",
    "You don’t have permission to upload or create files here" : "No tienes permisos para subir o crear archivos aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
    "New" : "Nuevo",
    "File name cannot be empty." : "El nombre del archivo no puede quedar vacío.",
    "Your storage is full, files can not be updated or synced anymore!" : "El almacenamiento está lleno, los archivos no se pueden seguir actualizando ni sincronizando",
    "Your storage is almost full ({usedSpacePercent}%)" : "El almacenamiento está casi lleno ({usedSpacePercent}%)",
    "Favorite" : "Favorito",
    "Folder" : "Carpeta",
    "New folder" : "Nueva Carpeta",
    "Upload" : "Subir",
    "A new file or folder has been <strong>created</strong>" : "Un archivo o carpeta ha sido <strong>creado</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un archivo o carpeta ha sido <strong>modificado</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>eliminado</strong>",
    "You created %1$s" : "Has creado %1$s",
    "%2$s created %1$s" : "%2$s creó %1$s",
    "You changed %1$s" : "Modificaste %1$s",
    "%2$s changed %1$s" : "%2$s modificó %1$s",
    "You deleted %1$s" : "Eliminaste %1$s",
    "%2$s deleted %1$s" : "%2$s eliminó %1$s",
    "File handling" : "Tratamiento de archivos",
    "Maximum upload size" : "Tamaño máximo de subida",
    "max. possible: " : "máx. posible:",
    "Save" : "Guardar",
    "Settings" : "Configuración",
    "WebDAV" : "WebDAV",
    "Upload too large" : "El tamaño del archivo que querés subir es demasiado grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que intentás subir sobrepasan el tamaño máximo ",
    "Text file" : "Archivo de texto"
},
"nplurals=2; plural=(n != 1);");
